<?php
#    IRM - The Information Resource Manager
#    Copyright (C) 1999 Yann Ramin
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License (in file COPYING) for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
include("../include/irm.inc");
require_once 'lib/Config.php';
require_once 'include/i18n.php';

AuthCheck("tech");

header("Location: ".$_SESSION['_sess_prevpage']);

if (!preg_match('/^[A-Za-z0-9_]+$/', $tablename))
{
	trigger_error(sprintf(_("Invalid table name: %s"),$tablename), E_USER_ERROR);
}

$DB = Config::Database();
$qname = $DB->getTextValue($name);
$query = "DELETE FROM $tablename WHERE (name = $qname)";
$DB->query($query);
logevent(-1, _("IRM"), 5, _("setup"), sprintf(_("%s removed entry %s from %s."),$IRMName,$name,$tablename));
